==> jc-1.4.0.tar.gz: soot/jimple/RealConstant.h <==
// public abstract class soot.jimple.RealConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class 3bd9379d3ff77f81 soot_jimple_NumericConstant
// @dep_class a7660b2b2ed7599f soot_jimple_RealConstant

// header file dependencies
// @dep_header soot_jimple_NumericConstant

#include "soot/jimple/NumericConstant.h"

#ifndef _JC_soot_jimple_RealConstant_H_
#define _JC_soot_jimple_RealConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_IntConstant$object;
struct _jc_soot_jimple_RealConstant$object;

// Typedefs
typedef struct _jc_soot_jimple_RealConstant$sub_refs	_jc_soot_jimple_RealConstant$sub_refs;
typedef struct _jc_soot_jimple_RealConstant$sub_nonrefs	_jc_soot_jimple_RealConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_RealConstant$refs	_jc_soot_jimple_RealConstant$refs;
typedef struct _jc_soot_jimple_RealConstant$nonrefs	_jc_soot_jimple_RealConstant$nonrefs;
typedef struct _jc_soot_jimple_RealConstant$object	_jc_soot_jimple_RealConstant$object;

typedef const struct _jc_soot_jimple_RealConstant$vmethods	_jc_soot_jimple_RealConstant$vmethods;
typedef const struct _jc_soot_jimple_RealConstant$vtable	_jc_soot_jimple_RealConstant$vtable;
typedef const struct _jc_soot_jimple_RealConstant$vtype	_jc_soot_jimple_RealConstant$vtype;

// Constructors
extern void _jc_soot_jimple_RealConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_RealConstant$object *);

// Virtual methods
extern struct _jc_soot_jimple_IntConstant$object *_jc_soot_jimple_RealConstant$method$cmpg$8477f215022b8620(_jc_env *, struct _jc_soot_jimple_RealConstant$object *, struct _jc_soot_jimple_RealConstant$object *);
extern struct _jc_soot_jimple_IntConstant$object *_jc_soot_jimple_RealConstant$method$cmpl$bf3c51f95381a77a(_jc_env *, struct _jc_soot_jimple_RealConstant$object *, struct _jc_soot_jimple_RealConstant$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_RealConstant$method_info$cmpg$8477f215022b8620;
extern _jc_method _jc_soot_jimple_RealConstant$method_info$cmpl$bf3c51f95381a77a;

// Virtual methods structure
struct _jc_soot_jimple_RealConstant$vmethods {
	struct _jc_soot_jimple_IntConstant$object	*(*cmpg$8477f215022b8620)(_jc_env *, struct _jc_soot_jimple_RealConstant$object *, struct _jc_soot_jimple_RealConstant$object *);
	struct _jc_soot_jimple_IntConstant$object	*(*cmpl$bf3c51f95381a77a)(_jc_env *, struct _jc_soot_jimple_RealConstant$object *, struct _jc_soot_jimple_RealConstant$object *);
};

// Vtable
struct _jc_soot_jimple_RealConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_jimple_NumericConstant$vmethods	soot_jimple_NumericConstant;
	_jc_soot_jimple_RealConstant$vmethods	soot_jimple_RealConstant;
};

// Vtype
struct _jc_soot_jimple_RealConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_RealConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_RealConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_RealConstant$refs {
    _jc_soot_jimple_RealConstant$sub_refs	soot_jimple_RealConstant;
    _jc_soot_jimple_NumericConstant$sub_refs	soot_jimple_NumericConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_RealConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_RealConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_jimple_NumericConstant$sub_nonrefs	soot_jimple_NumericConstant;
    _jc_soot_jimple_RealConstant$sub_nonrefs	soot_jimple_RealConstant;
};

// Object instance structure
struct _jc_soot_jimple_RealConstant$object {
	_jc_soot_jimple_RealConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_RealConstant$vtype	*vtype;
	_jc_soot_jimple_RealConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_RealConstant$vtype _jc_soot_jimple_RealConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_RealConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_RealConstant$class_object;

#endif	/* _JC_soot_jimple_RealConstant_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/RealConstant.h <==
// public abstract class soot.jimple.RealConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class 3bd9379d3ff77f81 soot_jimple_NumericConstant
// @dep_class a7660b2b2ed7599f soot_jimple_RealConstant

// header file dependencies
// @dep_header soot_jimple_NumericConstant

#include "soot/jimple/NumericConstant.h"

#ifndef _JC_soot_jimple_RealConstant_H_
#define _JC_soot_jimple_RealConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_IntConstant$object;
struct _jc_soot_jimple_RealConstant$object;

// Typedefs
typedef struct _jc_soot_jimple_RealConstant$sub_refs	_jc_soot_jimple_RealConstant$sub_refs;
typedef struct _jc_soot_jimple_RealConstant$sub_nonrefs	_jc_soot_jimple_RealConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_RealConstant$refs	_jc_soot_jimple_RealConstant$refs;
typedef struct _jc_soot_jimple_RealConstant$nonrefs	_jc_soot_jimple_RealConstant$nonrefs;
typedef struct _jc_soot_jimple_RealConstant$object	_jc_soot_jimple_RealConstant$object;

typedef const struct _jc_soot_jimple_RealConstant$vmethods	_jc_soot_jimple_RealConstant$vmethods;
typedef const struct _jc_soot_jimple_RealConstant$vtable	_jc_soot_jimple_RealConstant$vtable;
typedef const struct _jc_soot_jimple_RealConstant$vtype	_jc_soot_jimple_RealConstant$vtype;

// Constructors
extern void _jc_soot_jimple_RealConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_RealConstant$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_IntConstant$object *_jc_soot_jimple_RealConstant$method$cmpg$8477f215022b8620(_jc_env *, struct _jc_soot_jimple_RealConstant$object *, struct _jc_soot_jimple_RealConstant$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_IntConstant$object *_jc_soot_jimple_RealConstant$method$cmpl$bf3c51f95381a77a(_jc_env *, struct _jc_soot_jimple_RealConstant$object *, struct _jc_soot_jimple_RealConstant$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_RealConstant$method_info$cmpg$8477f215022b8620;
extern _jc_method _jc_soot_jimple_RealConstant$method_info$cmpl$bf3c51f95381a77a;

// Virtual methods structure
struct _jc_soot_jimple_RealConstant$vmethods {
	struct _jc_soot_jimple_IntConstant$object	*(*cmpg$8477f215022b8620)(_jc_env *, struct _jc_soot_jimple_RealConstant$object *, struct _jc_soot_jimple_RealConstant$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_IntConstant$object	*(*cmpl$bf3c51f95381a77a)(_jc_env *, struct _jc_soot_jimple_RealConstant$object *, struct _jc_soot_jimple_RealConstant$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_RealConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_jimple_NumericConstant$vmethods	soot_jimple_NumericConstant;
	_jc_soot_jimple_RealConstant$vmethods	soot_jimple_RealConstant;
};

// Vtype
struct _jc_soot_jimple_RealConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_RealConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_RealConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_RealConstant$refs {
    _jc_soot_jimple_RealConstant$sub_refs	soot_jimple_RealConstant;
    _jc_soot_jimple_NumericConstant$sub_refs	soot_jimple_NumericConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_RealConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_RealConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_jimple_NumericConstant$sub_nonrefs	soot_jimple_NumericConstant;
    _jc_soot_jimple_RealConstant$sub_nonrefs	soot_jimple_RealConstant;
};

// Object instance structure
struct _jc_soot_jimple_RealConstant$object {
	_jc_soot_jimple_RealConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_RealConstant$vtype	*vtype;
	_jc_soot_jimple_RealConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_RealConstant$vtype _jc_soot_jimple_RealConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_RealConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_RealConstant$class_object;

#endif	/* _JC_soot_jimple_RealConstant_H_ */
